@@ -20,9 +20,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <gtk/gtktreednd.h>
 #include <config.h>
+
 #include <string.h>
+
+#include <gtk/gtk.h>
+
 #include "pointer-list-model.h"
 #include "macros.h"
 
@@ -55,7 +58,7 @@ pointer_list_model_get_iter (GtkTreeModel *tree_model,
 			  GtkTreePath  *path)
 {
   PointerListModel *model;
-  GSequencePtr ptr;
+  GSequenceIter *ptr;
   int i;
 
   model = (PointerListModel *) tree_model;
@@ -65,7 +68,7 @@ pointer_list_model_get_iter (GtkTreeModel *tree_model,
   if (i >= g_sequence_get_length (model->pointers))
     return FALSE;
 
-  ptr = g_sequence_get_ptr_at_pos (model->pointers, i);
+  ptr = g_sequence_get_iter_at_pos (model->pointers, i);
 
   iter->stamp = model->stamp;
   iter->user_data = ptr;
@@ -84,11 +87,11 @@ pointer_list_model_get_path (GtkTreeModel *tree_model,
 
   g_return_val_if_fail (model->stamp == iter->stamp, NULL);
 
-  if (g_sequence_ptr_is_end (iter->user_data))
+  if (g_sequence_iter_is_end (iter->user_data))
     return NULL;
   
   path = gtk_tree_path_new ();
-  gtk_tree_path_append_index (path, g_sequence_ptr_get_position (iter->user_data));
+  gtk_tree_path_append_index (path, g_sequence_iter_get_position (iter->user_data));
 
   return path;
 }
@@ -106,7 +109,7 @@ pointer_list_model_get_value (GtkTreeModel *tree_model,
 
   g_return_if_fail (model->stamp == iter->stamp);
 
-  val = g_sequence_ptr_get_data (iter->user_data);
+  val = g_sequence_get (iter->user_data);
   
   switch (column)
     {
@@ -128,7 +131,7 @@ pointer_list_model_iter_nth_child (GtkTreeModel *tree_model,
 				int           n)
 {
   PointerListModel *model;
-  GSequencePtr child;
+  GSequenceIter *child;
 
   if (parent)
     return FALSE;
@@ -138,7 +141,7 @@ pointer_list_model_iter_nth_child (GtkTreeModel *tree_model,
   if (n >= g_sequence_get_length (model->pointers))
     return FALSE;
 
-  child = g_sequence_get_ptr_at_pos (model->pointers, n);
+  child = g_sequence_get_iter_at_pos (model->pointers, n);
 
   iter->stamp = model->stamp;
   iter->user_data = child;
@@ -156,9 +159,9 @@ pointer_list_model_iter_next (GtkTreeModel *tree_model,
 
   g_return_val_if_fail (model->stamp == iter->stamp, FALSE);
 
-  iter->user_data = g_sequence_ptr_next (iter->user_data);
+  iter->user_data = g_sequence_iter_next (iter->user_data);
 
-  return !g_sequence_ptr_is_end (iter->user_data);
+  return !g_sequence_iter_is_end (iter->user_data);
 }
 
 static gboolean
@@ -177,7 +180,7 @@ pointer_list_model_iter_children (GtkTreeModel *tree_model,
     return FALSE;
 
   iter->stamp = model->stamp;
-  iter->user_data = g_sequence_get_begin_ptr (model->pointers);
+  iter->user_data = g_sequence_get_begin_iter (model->pointers);
   
   return TRUE;
 }
@@ -421,7 +424,7 @@ pointer_list_model_add (PointerListModel *model, gpointer pointer)
 {
   GtkTreeIter iter;
   GtkTreePath *path;
-  GSequencePtr new_ptr;
+  GSequenceIter *new_ptr;
 
   if (g_hash_table_lookup (model->reverse_map, pointer))
     return FALSE;
@@ -451,7 +454,7 @@ pointer_list_model_insert (PointerListModel *model, gpointer pointer,
 {
   GtkTreeIter iter;
   GtkTreePath *path;
-  GSequencePtr new_ptr, before_ptr;
+  GSequenceIter *new_ptr, *before_ptr;
   gboolean is_end;
 
   if (g_hash_table_lookup (model->reverse_map, pointer))
@@ -460,7 +463,7 @@ pointer_list_model_insert (PointerListModel *model, gpointer pointer,
   before_ptr = g_hash_table_lookup (model->reverse_map, ins);
   g_assert (before_ptr != NULL);
 
-  is_end = g_sequence_ptr_is_end (g_sequence_ptr_next (before_ptr));
+  is_end = g_sequence_iter_is_end (g_sequence_iter_next (before_ptr));
 
   new_ptr = g_sequence_append (model->pointers, pointer);
 
@@ -471,7 +474,7 @@ pointer_list_model_insert (PointerListModel *model, gpointer pointer,
     case GTK_TREE_VIEW_DROP_AFTER:
     case GTK_TREE_VIEW_DROP_INTO_OR_AFTER:
       if (!is_end)
-        before_ptr = g_sequence_ptr_next (before_ptr);
+        before_ptr = g_sequence_iter_next (before_ptr);
       else
         before_ptr = NULL;
 
@@ -479,7 +482,7 @@ pointer_list_model_insert (PointerListModel *model, gpointer pointer,
   }
 
   if (before_ptr != NULL)
-    g_sequence_ptr_move_before (new_ptr, before_ptr);
+    g_sequence_move (new_ptr, g_sequence_iter_prev (before_ptr));
 
   g_hash_table_insert (model->reverse_map, pointer, new_ptr);
 
@@ -496,7 +499,7 @@ pointer_list_model_insert (PointerListModel *model, gpointer pointer,
 void
 pointer_list_model_remove_iter (PointerListModel *model, GtkTreeIter *iter)
 {
-  GSequencePtr ptr;
+  GSequenceIter *ptr;
   GtkTreePath *path;
   
   path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), iter);
@@ -505,7 +508,7 @@ pointer_list_model_remove_iter (PointerListModel *model, GtkTreeIter *iter)
   if (ptr == model->current_pointer)
     model->current_pointer = NULL;
 
-  g_hash_table_remove (model->reverse_map, g_sequence_ptr_get_data (ptr));
+  g_hash_table_remove (model->reverse_map, g_sequence_get (ptr));
   g_sequence_remove (ptr);
   
   model->stamp++;
@@ -535,7 +538,7 @@ pointer_list_model_clear (PointerListModel *model)
   while (g_sequence_get_length (model->pointers) > 0)
     {
       iter.stamp = model->stamp;
-      iter.user_data = g_sequence_get_begin_ptr (model->pointers);
+      iter.user_data = g_sequence_get_begin_iter (model->pointers);
       pointer_list_model_remove_iter (model, &iter);
     }
 }
@@ -544,7 +547,7 @@ void
 pointer_list_model_sort (PointerListModel *model, GCompareDataFunc sort_func)
 {
   GSequence *pointers;
-  GSequencePtr *old_order;
+  GSequenceIter **old_order;
   GtkTreePath *path;
   int *new_order;
   int length;
@@ -556,17 +559,17 @@ pointer_list_model_sort (PointerListModel *model, GCompareDataFunc sort_func)
   if (length <= 1)
     return;
   
-  /* Generate old order of GSequencePtrs. */
-  old_order = g_new (GSequencePtr, length);
+  /* Generate old order of GSequenceIters. */
+  old_order = g_new (GSequenceIter *, length);
   for (i = 0; i < length; ++i)
-    old_order[i] = g_sequence_get_ptr_at_pos (pointers, i);
+    old_order[i] = g_sequence_get_iter_at_pos (pointers, i);
 
   g_sequence_sort (pointers, sort_func, NULL);
 
   /* Generate new order. */
   new_order = g_new (int, length);
   for (i = 0; i < length; ++i)
-    new_order[i] = g_sequence_ptr_get_position (old_order[i]);
+    new_order[i] = g_sequence_iter_get_position (old_order[i]);
 
   path = gtk_tree_path_new ();
   
@@ -594,7 +597,7 @@ pointer_list_model_pointer_get_iter (PointerListModel *model,
 			       gpointer pointer,
 			       GtkTreeIter   *iter)
 {
-  GSequencePtr ptr;
+  GSequenceIter *ptr;
 
   ptr = g_hash_table_lookup (model->reverse_map, pointer);
   if (!ptr)
@@ -614,20 +617,20 @@ pointer_list_model_iter_get_pointer (PointerListModel *model, GtkTreeIter *iter)
 {
   g_return_val_if_fail (model->stamp == iter->stamp, NULL);
   
-  return g_sequence_ptr_get_data (iter->user_data);
+  return g_sequence_get (iter->user_data);
 }
 
 GList *
 pointer_list_model_get_pointers (PointerListModel *model)
 {
   GList *list = NULL;
-  GSequencePtr ptr;
+  GSequenceIter *ptr;
 
-  ptr = g_sequence_get_begin_ptr (model->pointers);
-  while (!g_sequence_ptr_is_end (ptr))
+  ptr = g_sequence_get_begin_iter (model->pointers);
+  while (!g_sequence_iter_is_end (ptr))
     {
-      list = g_list_prepend (list, g_sequence_ptr_get_data (ptr));
-      ptr = g_sequence_ptr_next (ptr);
+      list = g_list_prepend (list, g_sequence_get (ptr));
+      ptr = g_sequence_iter_next (ptr);
     }
 
   return g_list_reverse (list);
@@ -641,17 +644,17 @@ pointer_list_model_contains (PointerListModel *model,
 }
 
 static void
-remove_ptr (PointerListModel *model, GSequencePtr ptr)
+remove_ptr (PointerListModel *model, GSequenceIter *ptr)
 {
   GtkTreePath *path;
   
   path = gtk_tree_path_new ();
-  gtk_tree_path_append_index (path, g_sequence_ptr_get_position (ptr));
+  gtk_tree_path_append_index (path, g_sequence_iter_get_position (ptr));
 
   if (ptr == model->current_pointer)
     model->current_pointer = NULL;
   
-  g_hash_table_remove (model->reverse_map, g_sequence_ptr_get_data (ptr));
+  g_hash_table_remove (model->reverse_map, g_sequence_get (ptr));
   
   g_sequence_remove (ptr);
 
@@ -667,7 +670,7 @@ pointer_list_model_remove_delta (PointerListModel *model, GList *pointers)
   GHashTable *hash;
   GList *l, *remove = NULL;
   gpointer pointer;
-  GSequencePtr ptr;
+  GSequenceIter *ptr;
   
   if (g_sequence_get_length (model->pointers) == 0)
     return;
@@ -683,14 +686,14 @@ pointer_list_model_remove_delta (PointerListModel *model, GList *pointers)
   for (l = pointers; l; l = l->next)
     g_hash_table_insert (hash, l->data, GINT_TO_POINTER (TRUE));
  
-  ptr = g_sequence_get_begin_ptr (model->pointers);
-  while (!g_sequence_ptr_is_end (ptr))
+  ptr = g_sequence_get_begin_iter (model->pointers);
+  while (!g_sequence_iter_is_end (ptr))
     {
-      pointer = g_sequence_ptr_get_data (ptr);
+      pointer = g_sequence_get (ptr);
       if (!g_hash_table_lookup (hash, pointer))
 	remove = g_list_prepend (remove, ptr);
       
-      ptr = g_sequence_ptr_next (ptr);
+      ptr = g_sequence_iter_next (ptr);
     }
 
   for (l = remove; l; l = l->next)
@@ -711,11 +714,11 @@ pointer_list_model_get_current (PointerListModel *model)
   if (model->current_pointer == NULL)
     return NULL;
   
-  return g_sequence_ptr_get_data (model->current_pointer);
+  return g_sequence_get (model->current_pointer);
 }
 
 static void
-row_changed (PointerListModel *model, GSequencePtr ptr)
+row_changed (PointerListModel *model, GSequenceIter *ptr)
 {
   GtkTreeIter iter;
   GtkTreePath *path;
@@ -736,7 +739,7 @@ row_changed (PointerListModel *model, GSequencePtr ptr)
 gboolean
 pointer_list_model_set_current (PointerListModel *model, gpointer pointer)
 {
-  GSequencePtr ptr;
+  GSequenceIter *ptr;
   int len;
   
   g_return_val_if_fail (IS_POINTER_LIST_MODEL (model), FALSE);
@@ -768,12 +771,12 @@ pointer_list_model_set_current (PointerListModel *model, gpointer pointer)
 gpointer
 pointer_list_model_next (PointerListModel *model)
 {
-  GSequencePtr ptr;
+  GSequenceIter *ptr;
   
   g_return_val_if_fail (IS_POINTER_LIST_MODEL (model), NULL);
 
-  ptr = g_sequence_ptr_next (model->current_pointer);
-  if (g_sequence_ptr_is_end (ptr))
+  ptr = g_sequence_iter_next (model->current_pointer);
+  if (g_sequence_iter_is_end (ptr))
     return NULL;
 
   if (ptr)
@@ -783,20 +786,20 @@ pointer_list_model_next (PointerListModel *model)
       row_changed (model, model->current_pointer);
     }
 
-  return g_sequence_ptr_get_data (model->current_pointer);
+  return g_sequence_get (model->current_pointer);
 }
 
 gpointer
 pointer_list_model_prev (PointerListModel *model)
 {
-  GSequencePtr ptr;
+  GSequenceIter *ptr;
   
   g_return_val_if_fail (IS_POINTER_LIST_MODEL (model), NULL);
 
   if (!pointer_list_model_has_prev (model))
     return NULL;
 
-  ptr = g_sequence_ptr_prev (model->current_pointer);
+  ptr = g_sequence_iter_prev (model->current_pointer);
   if (ptr)
     {
       row_changed (model, model->current_pointer);
@@ -804,20 +807,20 @@ pointer_list_model_prev (PointerListModel *model)
       row_changed (model, model->current_pointer);
     }
 
-  return g_sequence_ptr_get_data (model->current_pointer);
+  return g_sequence_get (model->current_pointer);
 }
 
 gpointer
 pointer_list_model_first (PointerListModel *model)
 {
-  GSequencePtr ptr;
+  GSequenceIter *ptr;
   
   g_return_val_if_fail (IS_POINTER_LIST_MODEL (model), NULL);
 
   if (g_sequence_get_length (model->pointers) == 0)
     return NULL;
   
-  ptr = g_sequence_get_begin_ptr (model->pointers);
+  ptr = g_sequence_get_begin_iter (model->pointers);
   if (ptr)
     {
       row_changed (model, model->current_pointer);
@@ -825,22 +828,22 @@ pointer_list_model_first (PointerListModel *model)
       row_changed (model, model->current_pointer);
     }
 
-  return g_sequence_ptr_get_data (model->current_pointer);
+  return g_sequence_get (model->current_pointer);
 }
 
 gpointer
 pointer_list_model_last (PointerListModel *model)
 {
-  GSequencePtr ptr;
+  GSequenceIter *ptr;
   
   g_return_val_if_fail (IS_POINTER_LIST_MODEL (model), NULL);
 
   if (g_sequence_get_length (model->pointers) == 0)
     return NULL;
   
-  ptr = g_sequence_get_end_ptr (model->pointers);
+  ptr = g_sequence_get_end_iter (model->pointers);
   if (ptr)
-    ptr = g_sequence_ptr_prev (ptr);
+    ptr = g_sequence_iter_prev (ptr);
   if (ptr)
     {
       row_changed (model, model->current_pointer);
@@ -848,7 +851,7 @@ pointer_list_model_last (PointerListModel *model)
       row_changed (model, model->current_pointer);
     }
 
-  return g_sequence_ptr_get_data (model->current_pointer);
+  return g_sequence_get (model->current_pointer);
 }
 
 gboolean
@@ -866,14 +869,14 @@ pointer_list_model_has_prev (PointerListModel *model)
   if (!model->current_pointer)
     return FALSE;
 
-  return (g_sequence_ptr_get_position (model->current_pointer) > 0);
+  return (g_sequence_iter_get_position (model->current_pointer) > 0);
 }
 
 gboolean
 pointer_list_model_has_next (PointerListModel *model)
 {
   int len;
-  GSequencePtr ptr;
+  GSequenceIter *ptr;
 
   g_return_val_if_fail (IS_POINTER_LIST_MODEL (model), FALSE);
 
@@ -885,9 +888,9 @@ pointer_list_model_has_next (PointerListModel *model)
   if (!model->current_pointer)
     return FALSE;
 
-  ptr = g_sequence_ptr_next (model->current_pointer);
+  ptr = g_sequence_iter_next (model->current_pointer);
 
-  return !g_sequence_ptr_is_end (ptr);
+  return !g_sequence_iter_is_end (ptr);
 }
 
 gboolean
