@@ -21,7 +21,7 @@ namespace Muine
 {
 	// TODO: Can we make this inherit from GConf.Client?
 	//	That would make this class nearly empty.
-	public sealed class Config 
+	public static class Config 
 	{
 		// Variables
 		private static GConf.Client gconf_client;
@@ -49,7 +49,7 @@ namespace Muine
 		/// </returns>
 		public static object Get (string key)
 		{
-		       return gconf_client.Get (key);
+			return gconf_client.Get (key);
 		}
 		
 		/// <summary>
@@ -66,17 +66,17 @@ namespace Muine
 		///	If that fails, <paramref name="default_val" /> is returned.
 		/// </returns>
 		public static object Get (string key, object default_val)
-	        {
-	                object val;
+		{
+			object val;
 
-	                try {
-	                        val = Get (key);
-	                } catch {
-	                        val = default_val;
-	                }
+			try {
+				val = Get (key);
+			} catch {
+				val = default_val;
+			}
 
-	                return val;
-	        }
+			return val;
+		}
 
 		// Methods :: Public :: Set
 		/// <summary>
@@ -88,10 +88,10 @@ namespace Muine
 		/// <param name="val">
 		///	The value.
 		/// </param>
-	        public static void Set (string key, object val)
-	        {
-	        	gconf_client.Set (key, val);        	
-	        }
+		public static void Set (string key, object val)
+		{
+			gconf_client.Set (key, val);        	
+		}
 
 		// Methods :: Public :: AddNotify
 		/// <summary>
@@ -103,7 +103,8 @@ namespace Muine
 		/// <param name="notify">
 		///	The <see cref="GConf.NotifyEventHandler" />.
 		/// </param>
-		public static void AddNotify (string key, GConf.NotifyEventHandler notify)
+		public static void AddNotify
+		  (string key, GConf.NotifyEventHandler notify)
 		{
 			gconf_client.AddNotify (key, notify);
 		}
