@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005 Tamara Roberson <foxxygirltamara@gmail.com>
+ * Copyright (C) 2005 Tamara Roberson <tamara.roberson@gmail.com>
  * Copyright (C) 2003, 2004, 2005 Jorn Baayen <jbaayen@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -22,7 +22,7 @@ using System;
 using System.Collections;
 using System.IO;
 using Gtk;
-using Mono.Posix;
+using Mono.Unix;
 
 namespace Muine
 {
@@ -40,11 +40,12 @@ namespace Muine
 			Catalog.GetString ("Untitled");
 
 		// Constructor
-		public SaveDialog () 
-		: base (string_title, FileChooserAction.Save, GConfKeyDefaultPlaylistFolder)
+		public SaveDialog ()
+		  : base (string_title, FileChooserAction.Save,
+		    GConfKeyDefaultPlaylistFolder)
 		{
 			base.CurrentName = string_save_default;
-			base.Response += new ResponseHandler (OnResponse);
+			base.Response += OnResponse;
 			base.Visible = true;
 		}
 
